@@ -583,7 +583,7 @@ eel_background_set_image_uri_helper (EelBackground *background,
 	GFile *f;
 	GFileInfo *info;
 
-	g_return_val_if_fail (EEL_IS_BACKGROUND (background), FALSE);
+	g_assert (EEL_IS_BACKGROUND (background));
 
 	mtime = background->details->image_mtime;
 	if (image_uri != NULL) {
@@ -683,7 +683,7 @@ eel_background_receive_dropped_background_image (EelBackground *background,
 gboolean
 eel_background_is_set (EelBackground *background)
 {
-	g_return_val_if_fail (EEL_IS_BACKGROUND (background), FALSE);
+	g_assert (EEL_IS_BACKGROUND (background));
 
 	return background->details->color != NULL
 		|| background->details->image_uri != NULL;
