@@ -26,8 +26,6 @@
 #define EEL_PREFERENCES_H
 
 #include <glib.h>
-#include <gtk/gtkobject.h>
-#include <eel/eel-string-list.h>
 #include <eel/eel-gconf-extensions.h>
 
 G_BEGIN_DECLS
@@ -45,12 +43,20 @@ void           eel_preferences_set_boolean                     (const char
 int            eel_preferences_get_integer                     (const char              *name);
 void           eel_preferences_set_integer                     (const char              *name,
 								int                      int_value);
+int            eel_preferences_get_enum                        (const char              *name);
+void           eel_preferences_set_enum                        (const char              *name,
+								int                      int_value);
 char *         eel_preferences_get                             (const char              *name);
 void           eel_preferences_set                             (const char              *name,
 								const char              *string_value);
-EelStringList *eel_preferences_get_string_list                 (const char              *name);
-void           eel_preferences_set_string_list                 (const char              *name,
-								const EelStringList     *string_list_value);
+char **        eel_preferences_get_string_array                 (const char              *name);
+void           eel_preferences_set_string_array                 (const char              *name,
+								 char                   **strv_value);
+
+void           eel_preferences_unset                            (const char              *name);
+
+/* Writability of a key */
+gboolean       eel_preferences_key_is_writable                 (const char              *name);
 
 /* Callbacks */
 void           eel_preferences_add_callback                    (const char              *name,
@@ -67,16 +73,18 @@ void           eel_preferences_remove_callback                 (const char
 /* Variables that are automatically updated (lightweight "callbacks") */
 void           eel_preferences_add_auto_string                 (const char              *name,
 								const char             **storage);
-void           eel_preferences_add_auto_string_list            (const char              *name,
-								const EelStringList    **storage);
+void           eel_preferences_add_auto_string_array           (const char              *name,
+								char                  ***storage);
 void           eel_preferences_add_auto_integer                (const char              *name,
 								int                     *storage);
+void           eel_preferences_add_auto_enum                   (const char              *name,
+								int                     *storage);
 void           eel_preferences_add_auto_boolean                (const char              *name,
 								gboolean                *storage);
 void           eel_preferences_remove_auto_string              (const char              *name,
 								const char             **storage);
-void           eel_preferences_remove_auto_string_list         (const char              *name,
-								const EelStringList    **storage);
+void           eel_preferences_remove_auto_string_array        (const char              *name,
+								char                  ***storage);
 void           eel_preferences_remove_auto_integer             (const char              *name,
 								int                     *storage);
 void           eel_preferences_remove_auto_boolean             (const char              *name,
@@ -100,8 +108,8 @@ void        eel_preferences_set_emergency_fallback_integer     (const char    *n
 								int            value);
 void        eel_preferences_set_emergency_fallback_boolean     (const char    *name,
 								gboolean       value);
-void        eel_preferences_set_emergency_fallback_string_list (const char    *name,
-								EelStringList *list);
+void        eel_preferences_set_emergency_fallback_string_array(const char    *name,
+								char         **value);
 GConfValue *eel_preferences_get_emergency_fallback             (const char    *name);
 
 
